:mod:`xoutil.functools` - Higher-order functions and operations on callable objects
===================================================================================

.. automodule:: xoutil.functools
   :members: lru_cache

.. autofunction:: compose(*funcs, math=True)

.. autofunction:: power(*funcs, times)

.. autoclass:: ctuple
